/*
 * Copyright (C) 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.tools.metalava.model.testsuite.typeitem

import com.android.tools.metalava.model.testsuite.BaseModelTest
import com.android.tools.metalava.testing.kotlin
import com.google.common.truth.Truth.assertThat
import org.junit.Test

class CommonTypeAliasTest : BaseModelTest() {

    @Test
    fun `Test typealias of generic type`() {
        runCodebaseTest(
            kotlin(
                """
                    package test.pkg

                    class GenericBar<A, B>

                    typealias StringIntBar = GenericBar<String?, Int>

                    class Foo<T> {
                        fun method(): StringIntBar? = null
                    }
                """
            ),
        ) {
            val fooClass = codebase.assertClass("test.pkg.Foo")
            val method = fooClass.methods().single()
            assertThat(method.kotlinLikeDescription())
                .isEqualTo(
                    "fun method(): test.pkg.GenericBar<java.lang.String?,java.lang.Integer>?"
                )
        }
    }
}
